
.. role:: bash(code)
   :language: bash

.. image:: https://github.com/iplweb/bpp/raw/dev/src/bpp/static/bpp/images/logo_bpp.png
  :width: 480 px
  :align: center
  :alt: Logo projektu

.. image:: https://circleci.com/gh/iplweb/bpp/tree/master.svg?style=svg
   :target: https://circleci.com/gh/iplweb/bpp

.. image:: https://readthedocs.org/projects/bpp/badge/?version=latest
   :target: http://bpp.readthedocs.io/pl/latest/?badge=latest
   :alt: Dokumentacja

.. image:: https://coveralls.io/repos/github/iplweb/bpp/badge.svg
   :target: https://coveralls.io/github/iplweb/bpp
   :alt: Coverage


O projekcie
-----------

Bibliografia Publikacji Pracowników to system informatyczny do zarządzania
bibliografią publikacji pracowników naukowych. Oprogramowanie przeznaczone
jest dla bibliotek naukowych i uniwersyteckich w Polsce.

Oprogramowanie dystrybuowane jest na zasadach otwartoźródłowej `licencja MIT`_.

Dokumentacja dostępna jest na stronie https://bpp.readthedocs.io/ .

Wersja demo serwisu
-------------------

Live-demo serwisu dostępne jest pod adresem http://bppdemo.iplweb.pl . W razie
pytań lub problemów z dostępem do serwisu demonstracyjnego prosimy o kontakt
pod adresem e-mail michal.dtz@gmail.com.

Obsługa komercyjna
------------------

Jeżeli jesteś bibliotekarzem i szukasz sposobu na szybkie wdrożenie systemu BPP
w swojej instytucji, zapraszam na stronę firmy IPLWeb_ . Znajdziesz tam m.in.
kontener maszyny wirtualnej zawierającej pre-instalowany system BPP, gotowy do
pracy, jak równiez bogatą ofertę wsparcia komercyjnego. Szczegóły na stronie
projektu http://bpp.iplweb.pl/

.. _IPLWeb: http://bpp.iplweb.pl/
.. _licencja MIT: https://pl.wikipedia.org/wiki/Licencja_MIT
